@@ -23,16 +23,17 @@
 # based on libipodsync.py (2006-04-05 Thomas Perl)
 # Ported to gPodder 3 by Joseph Wickremasinghe in June 2012
 
-import gpodder
-
-from gpodder import util
-from gpodder import services
-from gpodder import download
-
+import calendar
+import glob
 import logging
+import os.path
+import time
+
+import gpodder
+from gpodder import download, services, util
+
 logger = logging.getLogger(__name__)
 
-import calendar
 
 _ = gpodder.gettext
 
@@ -60,9 +61,6 @@ try:
 except:
     logger.warning('Could not find eyed3.mp3')
 
-import os.path
-import glob
-import time
 
 if pymtp_available:
     class MTP(pymtp.MTP):
@@ -145,6 +143,46 @@ def get_track_length(filename):
     # Default is three hours (to be on the safe side)
 
 
+def episode_filename_on_device(config, episode):
+    """
+    :param gpodder.config.Config config: configuration (for sync options)
+    :param gpodder.model.PodcastEpisode episode: episode to get filename for
+    :return str: basename minus extension to use to save episode on device
+    """
+    # get the local file
+    from_file = episode.local_filename(create=False)
+    # get the formated base name
+    filename_base = util.sanitize_filename(episode.sync_filename(
+        config.device_sync.custom_sync_name_enabled,
+        config.device_sync.custom_sync_name),
+        config.device_sync.max_filename_length)
+    # add the file extension
+    to_file = filename_base + os.path.splitext(from_file)[1].lower()
+
+    # dirty workaround: on bad (empty) episode titles,
+    # we simply use the from_file basename
+    # (please, podcast authors, FIX YOUR RSS FEEDS!)
+    if os.path.splitext(to_file)[0] == '':
+        to_file = os.path.basename(from_file)
+    return to_file
+
+
+def episode_foldername_on_device(config, episode):
+    """
+    :param gpodder.config.Config config: configuration (for sync options)
+    :param gpodder.model.PodcastEpisode episode: episode to get folder name for
+    :return str: folder name to save episode to on device
+    """
+    if config.device_sync.one_folder_per_podcast:
+        # Add channel title as subfolder
+        folder = episode.channel.title
+        # Clean up the folder name for use on limited devices
+        folder = util.sanitize_filename(folder, config.device_sync.max_filename_length)
+    else:
+        folder = None
+    return folder
+
+
 class SyncTrack(object):
     """
     This represents a track that is on a device. You need
@@ -207,7 +245,7 @@ class Device(services.ObservableService):
             logger.warning('Not syncing disks. Unmount your device before unplugging.')
         return True
 
-    def add_sync_tasks(self,tracklist, force_played=False, done_callback=None):
+    def add_sync_tasks(self, tracklist, force_played=False, done_callback=None):
         for track in list(tracklist):
             # Filter tracks that are not meant to be synchronized
             does_not_exist = not track.was_downloaded(and_exists=True)
@@ -413,7 +451,7 @@ class iPodDevice(Device):
         gpod.itdb_track_unlink(track)
         util.delete_file(filename)
 
-    def add_track(self, episode,reporthook=None):
+    def add_track(self, episode, reporthook=None):
         self.notify('status', _('Adding %s') % episode.title)
         tracklist = gpod.sw_get_playlist_tracks(self.podcasts_playlist)
         podcasturls = [track.podcasturl for track in tracklist]
@@ -527,12 +565,8 @@ class MP3PlayerDevice(Device):
         return False
 
     def get_episode_folder_on_device(self, episode):
-        if self._config.device_sync.one_folder_per_podcast:
-            # Add channel title as subfolder
-            folder = episode.channel.title
-            # Clean up the folder name for use on limited devices
-            folder = util.sanitize_filename(folder,
-                self._config.device_sync.max_filename_length)
+        folder = episode_foldername_on_device(self._config, episode)
+        if folder:
             folder = os.path.join(self.destination, folder)
         else:
             folder = self.destination
@@ -540,25 +574,9 @@ class MP3PlayerDevice(Device):
         return folder
 
     def get_episode_file_on_device(self, episode):
-        # get the local file
-        from_file = episode.local_filename(create=False)
-        # get the formated base name
-        filename_base = util.sanitize_filename(episode.sync_filename(
-            self._config.device_sync.custom_sync_name_enabled,
-            self._config.device_sync.custom_sync_name),
-            self._config.device_sync.max_filename_length)
-        # add the file extension
-        to_file = filename_base + os.path.splitext(from_file)[1].lower()
+        return episode_filename_on_device(self._config, episode)
 
-        # dirty workaround: on bad (empty) episode titles,
-        # we simply use the from_file basename
-        # (please, podcast authors, FIX YOUR RSS FEEDS!)
-        if os.path.splitext(to_file)[0] == '':
-            to_file = os.path.basename(from_file)
-
-        return to_file
-
-    def add_track(self, episode,reporthook=None):
+    def add_track(self, episode, reporthook=None):
         self.notify('status', _('Adding %s') % episode.title)
 
         # get the folder on the device
@@ -744,7 +762,7 @@ class MTPDevice(Device):
         try:
             mtp = mtp.replace(" ", "0")
             # replace blank with 0 to fix some invalid string
-            d = time.strptime(mtp[:8] + mtp[9:13],"%Y%m%d%H%M%S")
+            d = time.strptime(mtp[:8] + mtp[9:13], "%Y%m%d%H%M%S")
             _date = calendar.timegm(d)
             if len(mtp) == 20:
                 # TIME ZONE SHIFTING: the string contains a hour/min shift relative to a time zone
