@@ -29,44 +29,41 @@ This module provides helper and utility functions for gPodder that
 are not tied to any specific part of gPodder.
 
 """
+import collections
+import datetime
+import glob
+import gzip
+import http.client
+import io
+import itertools
 import json
-
-import gpodder
-
+import locale
 import logging
-logger = logging.getLogger(__name__)
-
+import mimetypes
 import os
 import os.path
 import platform
-import glob
-import stat
+import re
 import shlex
 import shutil
 import socket
-import sys
+import stat
 import string
-
-import re
 import subprocess
-from html.entities import entitydefs
-import time
-import gzip
-import datetime
+import sys
 import threading
-
-import http.client
-import webbrowser
-import mimetypes
-import itertools
+import time
 import urllib.error
 import urllib.parse
 import urllib.request
-
-import io
+import webbrowser
 import xml.dom.minidom
+from html.entities import entitydefs
+
+import gpodder
+
+logger = logging.getLogger(__name__)
 
-import collections
 
 if sys.hexversion < 0x03000000:
     from html.parser import HTMLParser
@@ -92,7 +89,6 @@ _ = gpodder.gettext
 N_ = gpodder.ngettext
 
 
-import locale
 try:
     locale.setlocale(locale.LC_ALL, '')
 except Exception as e:
@@ -443,7 +439,7 @@ def file_age_to_string(days):
     if days < 1:
         return ''
     else:
-        return N_('%(count)d day ago', '%(count)d days ago', days) % {'count':days}
+        return N_('%(count)d day ago', '%(count)d days ago', days) % {'count': days}
 
 
 def is_system_file(filename):
@@ -642,7 +638,7 @@ def remove_html_tags(html):
     result = re_unicode_entities.sub(lambda x: chr(int(x.group(1))), result)
 
     # Convert named HTML entities to their unicode character
-    result = re_html_entities.sub(lambda x: entitydefs.get(x.group(1),''), result)
+    result = re_html_entities.sub(lambda x: entitydefs.get(x.group(1), ''), result)
 
     # Convert more than two newlines to two newlines
     result = re.sub('([\r\n]{2})([\r\n])+', '\\1', result)
@@ -1373,7 +1369,8 @@ def format_seconds_to_hour_min_sec(seconds):
     """
 
     if seconds < 1:
-        return N_('%(count)d second', '%(count)d seconds', seconds) % {'count':seconds}
+        return N_('%(count)d second', '%(count)d seconds',
+                  seconds) % {'count': seconds}
 
     result = []
 
@@ -1386,13 +1383,16 @@ def format_seconds_to_hour_min_sec(seconds):
     seconds = seconds % 60
 
     if hours:
-        result.append(N_('%(count)d hour', '%(count)d hours', hours) % {'count':hours})
+        result.append(N_('%(count)d hour', '%(count)d hours',
+                         hours) % {'count': hours})
 
     if minutes:
-        result.append(N_('%(count)d minute', '%(count)d minutes', minutes) % {'count':minutes})
+        result.append(N_('%(count)d minute', '%(count)d minutes',
+                         minutes) % {'count': minutes})
 
     if seconds:
-        result.append(N_('%(count)d second', '%(count)d seconds', seconds) % {'count':seconds})
+        result.append(N_('%(count)d second', '%(count)d seconds',
+                         seconds) % {'count': seconds})
 
     if len(result) > 1:
         return (' ' + _('and') + ' ').join((', '.join(result[:-1]), result[-1]))
@@ -1468,16 +1468,16 @@ def convert_bytes(d):
     return d
 
 
-def sanitize_filename(filename, max_length=0):
+def sanitize_filename(filename, max_length):
     """
     Generate a sanitized version of a filename; trim filename
     if greater than max_length (0 = no limit).
 
-    >>> sanitize_filename('https://www.host.name/feed')
+    >>> sanitize_filename('https://www.host.name/feed', 0)
     'https___www.host.name_feed'
-    >>> sanitize_filename('Binärgewitter')
+    >>> sanitize_filename('Binärgewitter', 0)
     'Binärgewitter'
-    >>> sanitize_filename('Cool feed (ogg)')
+    >>> sanitize_filename('Cool feed (ogg)', 0)
     'Cool feed (ogg)'
     >>> sanitize_filename('Cool feed (ogg)', 1)
     'C'
@@ -1614,7 +1614,7 @@ def relpath(p1, p2):
     def pathsplit(s):
         return s.split(os.path.sep)
 
-    (common,l1,l2) = commonpath(pathsplit(p1), pathsplit(p2))
+    (common, l1, l2) = commonpath(pathsplit(p1), pathsplit(p2))
     p = []
     if len(l1) > 0:
         p = [('..' + os.sep) * len(l1)]
@@ -1775,7 +1775,7 @@ def get_update_info():
     data = urlopen(url).read().decode('utf-8')
     info = json.loads(data)
 
-    latest_version = info.get('tag_name','').replace('gpodder-','')
+    latest_version = info.get('tag_name', '').replace('gpodder-', '')
     release_date = info['published_at']
 
     release_parsed = datetime.datetime.strptime(release_date, '%Y-%m-%dT%H:%M:%SZ')
